@@ -563,6 +563,10 @@ oO񍐁Apb`}܂B
 =item * ӒlƂĂ Sjis::substr
 
     Sjis::substr  CORE::substr Ƃ͈قȂAӒlƂĈƂł܂B
+    ̈ꕔύXꍇ́ASjis::substr 4Ԗڂ̈ƂĒu
+    w肵܂B
+    
+    Sjis::substr($string, 13, 4, "JPerl");
 
 =item * ϐ $`  $& ͋@\܂
 
